@@ -4,6 +4,8 @@
 
 #   Standard module loading
 use strict;
+use 5.010;
+use utf8;
 use warnings;
 use Log::Trivial;
 
